/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzStrings = add_options(env, index, attributes)
// Generate necessary options for TikZ
//
// Syntax
// tikzStrings = add_options(env, index, attributes)
//
// Parameters
//      env: a string resembling the targeted environment for options
//      index: constant for accessing the indexed element of attributes
//      attributes: struct containing plot information
//      tikzStrings: column vector containing generated strings
//
// Description
// Generate a bunch of strings in a column vector containing all the necessary options
// for displaying data in the given environment. Env can be:
// axis
// addplot
//
// Examples
// choose_plot_example("simple");
// attributes = gather_graphic_attributes();
// tikzStrings = add_options("axis", 1, attributes)
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("env", "l") || ~isdef("index", "l") || ~isdef("attributes", "l")
        message = "%s: insufficient number of input arguments, 3 expected!\n";
        error(msprintf(message, "add_options"))
    end

    if typeof(env) ~= "string"
        message = "%s: input argument env is not of type string!\n";
        error(msprintf(message, "add_environment_beginning"))
    end

    if ~isstruct(attributes)
        message = "%s: input argument attributes is not of type struct!\n";
        error(msprintf(message, "add_environment_beginning"))
    end

    // Load internals
    path = get_function_path("add_options");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    select env
        case "axis" then
            if (length(attributes.axes) < index) || (index < 0)
                message = "%s: input argument index is out of bounds.\n";
                error(msprintf(message, "add_color_defines"))
            end
            element = attributes.axes{index};
            tikzStrings = axis_options(element);
        case "addplot" then
            if (length(attributes.polylines) < index) || (index < 0)
                message = "%s: input argument index is out of bounds.\n";
                error(msprintf(message, "add_color_defines"))
            end
            element = attributes.polylines{index};
            tikzStrings = addplot_options(element);
        else
            message = "%s: environment %s not supported.\n";
            error(msprintf(message, "add_options", env))
    end

    tikzStrings($+1) = msprintf("]\n");
endfunction
