/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function axes = create_axes_struct(figure)
// Create a struct for each axes found and add necessary data to it
//
// Syntax
// axes = create_axes_struct(figure)
//
// Parameters
//      figure: figure handle
//      axes: struct with axes data
//
// Description
// Creates a struct for each axes in figure and add the following fields:
// .handle: axis handle
// .visible: axis visibility (on|off)
// .associated_legend: legend handle bound to this axis
// .children: handle of the axis' children
// .x_bounds: a row-vector with upper and lower x axis bound
// .y_bounds: a row-vector with upper and lower y axis bound
// .x_label: string with x label
// .y_label: string with y label
// .color.background: string with color name for axis backround
// .color.x_label_background: string with color name for x label background
// .color.y_label_background: string with color name for y label background
// .color.x_label_foreground: string with color name for x label foreground
// .color.y_label_foreground: string with color name for y label foreground
// .title: the axis title
// .title_font: font used for the axis title (integer from 1-10)
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("figure", "l")
        message = "%s: please provide an input argument!\n";
        error(msprintf(message, "create_axes_struct"))
    end

    if typeof(figure) ~= "handle"
        message = "%s: input argument is not a handle!\n";
        error(msprintf(message, "create_axes_struct"));
    else
        if figure.type ~= "Figure"
            message = "%s: handle is not of type Figure!\n"
            error(msprintf(message, "create_axes_struct"));
        end
    end

    // Load internals
    path = get_function_path("create_axes_struct");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    axes = cell();

    for axis = get(figure, "children")'
        if axis.type ~= "Axes"
            continue;
        end

        axes{$+1} = struct();

        //TODO we might need more entries
        axes{$}.handle = axis;
        axes{$}.visible = axis.visible;
        if get_associated_legend(axis) ~= ""
            axes{$}.associated_legend = get_associated_legend(axis);
        end
        axes{$}.children = axis.children;
        [lower, upper] = get_axis_bounds(axis, "x");
        axes{$}.x_bounds = [lower, upper];
        [lower, upper] = get_axis_bounds(axis, "y");
        axes{$}.y_bounds = [lower, upper];
        axes{$}.x_label = axis.x_label.text;
        axes{$}.y_label = axis.y_label.text;
        axes{$}.color.background = to_color_name(axis.background, figure.color_map);
        axes{$}.color.x_label_background = to_color_name(axis.x_label.background, figure.color_map);
        axes{$}.color.x_label_foreground = to_color_name(axis.x_label.foreground, figure.color_map);
        axes{$}.color.y_label_background = to_color_name(axis.y_label.background, figure.color_map);
        axes{$}.color.y_label_foreground = to_color_name(axis.y_label.foreground, figure.color_map);
        axes{$}.title = axis.title.text;
        axes{$}.title_font = axis.title.font_style;
    end

    if length(axes) < 1
        message = "%s: no axes detected.\n";
        error(msprintf(message, "create_axes_struct"));
    end
endfunction
