/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function legends = create_legends_struct(axes, colormap)
// Create a struct for each legend found and add necessary data to it
//
// Syntax
// legends = create_legends_struct(axes)
//
// Parameters
//      axes: cell with axes handles
//      colormap: the figures colormap
//      legends: struct with legends data
//
// Description
// Creates a struct for each legend found in any axis and add the following fields:
// .handle: legend handle
// .links: matrix of handles of associated polylines
// .visible: legend visibility (on|off)
// .text: a column vector containing the legends entries
// .position: a row vector containing the legends upper left coordinates
// .color.font: font used for the legends entries
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("axes", "l") || ~isdef("colormap", "l")
        message = "%s: insufficient number of input arguments, 2 expected!\n";
        error(msprintf(message, "create_legends_struct"))
    end

    if ~iscell(axes)
        message = "%s: input argument axes is not a cell!\n";
        error(msprintf(message, "create_legends_struct"))
    end

    if (~ismatrix(colormap)) || (typeof(colormap) ~= "constant")
        message = "%s: input argument colormap is not a matrix of constants!\n";
        error(msprintf(message, "create_legends_struct"))
    end

    // Load internals
    path = get_function_path("create_legends_struct");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    legends = cell();

    if isempty(axes)
        message = "%s: no children found for axes!";
        warning(msprintf(gettext(message)), "create_legends_struct");
        return
    end

    for axis = axes{:}
        if axis.visible == "off"
            continue;
        end

        for axisChild = axis.children'
            if (axisChild.type ~= "Legend") || (axisChild.visible == "off")
                continue;
            end

            legends{$+1} = struct();

            //TODO we might need more entries
            legends{$}.handle = axisChild;
            legends{$}.links = axisChild.links;
            legends{$}.visible = axisChild.visible;
            // texts are stored in reversed order compared to links
            legends{$}.text = flipdim(axisChild.text, 1);
            legends{$}.position = axisChild.position;
            legends{$}.color.font = to_color_name(axisChild.font_color, colormap);

        end
    end
endfunction
