/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function polylines = create_polylines_struct(axes, colormap)
// Create a struct for each polyline found and add necessary data to it
//
// Syntax
// polylines = create_polylines_struct(axes)
//
// Parameters
//      axes: cell with axes handles
//      colormap: the figures colormap
//      polylines: struct with polylines data
//
// Description
// Creates a struct for each polyline found in any axis and add the following fields:
// .handle: polyline handle
// .associated_axis: axis handle which polyline belongs to
// .visible: polyline visibility (on|off)
// .data: plotting data representing the polyline
// .line: struct with fields associated to the line representation
// Fields in line: style, color.foreground, color.background
// .mark: struct with fields associated to the mark representation
// Fields in mark: mode, style, color.foreground, color.background
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("axes", "l") || ~isdef("colormap", "l")
        message = "%s: insufficient number of input arguments, 2 expected!\n";
        error(msprintf(message, "create_polylines_struct"))
    end

    if ~iscell(axes)
        message = "%s: input argument axes is not of type cell!\n";
        error(msprintf(message, "create_polylines_struct"))
    end

    if (~ismatrix(colormap)) || (typeof(colormap) ~= "constant")
        message = "%s: input argument colormap is not a matrix of constants!\n";
        error(msprintf(message, "create_polylines_struct"))
    end

    // Load internals
    path = get_function_path("create_polylines_struct");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    polylines = cell();

    if isempty(axes)
        message = "%s: no children found for axes!";
        warning(msprintf(gettext(message)), "create_polylines_struct");
        return
    end

    for axis = axes{:}
        if axis.visible == "off"
            continue;
        end

        for axisChild = axis.children'
            if (axisChild.type ~= "Compound") || (axisChild.visible == "off")
                continue;
            end

            for line = axisChild.children'
                if (line.type ~= "Polyline") || (line.visible == "off")
                    continue;
                end

                polylines{$+1} = struct();

                polylines{$}.handle = line;
                polylines{$}.associated_axis = axis.handle;
                if isfield(axis, "associated_legend") && length(axis.associated_legend) > 0
                    polylines{$}.associated_legend = axis.associated_legend;
                end
                polylines{$}.visible = line.visible;
                polylines{$}.data = line.data;
                polylines{$}.line = struct();
                polylines{$}.mark = struct();

                polylines{$}.line.color.foreground = to_color_name(line.foreground, colormap);
                polylines{$}.line.color.background = to_color_name(line.background, colormap);
                polylines{$}.line.style = line.line_style;

                polylines{$}.mark.mode = line.mark_mode;
                polylines{$}.mark.color.foreground = to_color_name(line.mark_foreground, colormap);
                polylines{$}.mark.color.background = to_color_name(line.mark_background, colormap);
                polylines{$}.mark.style = line.mark_style;
            end
        end
    end
endfunction
