/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

 */
function tikzString = generate_nested_string(env, options, values)
// Return a string with the given environment and options set
//
// Syntax
// tikzString = generate_nested_string(env, options, values)
//
// Parameters
//      env: string with element name
//      options: vector of strings with LateX tags
//      values: each element in options will be set to the element in values
//
// Description
// Depending on the given environment, this function sets a multiple of options
// to a value from the values vector. Currently supported options are:
// font, draw, legend cell align, align and fill.
//
// Examples
// env = "legend style";
// options = ["legend cell allign, align, draw"];
// values = ["left", "left", "white"];
// ts = generate_nested_string(env, options, values);
//
// Authors
// Manuel Csapo, 2018

    if ~isdef("env", "l") || ~isdef("options", "l") || ~isdef("values", "l")
        message = "%s: insufficient number of input arguments, 3 expected!\n";
        error(msprintf(message, "set_styles"))
    end

    if ~iscell(options)
        message = "%s: input argument options is not a cell!\n";
        error(msprintf(message, "set_styles"))
    end

    if ~iscell(values)
        message = "%s: input argument values is not a cell!\n";
        error(msprintf(message, "set_styles"))
    end

    if iscolumn(options)
        options = options';
    end

    if iscolumn(values)
        values = values';
    end

    [row, column] = size(options);
    if row > 1
        message = "%s: input argument options has wrong dimension, must be a 1 x n or n x 1 cell array!\n";
        error(msprintf(message, "set_styles"))
    end

    [row, column] = size(values);
    if row > 1
        message = "%s: input argument options has wrong dimension, must be a 1 x n or n x 1 cell array!\n";
        error(msprintf(message, "set_styles"))
    end

    if size(options) ~= size(values)
        message = "%s: dimension of options and values do not match";
        error(msprintf(message, "set_styles"))
    end

    // Load internals
    path = get_function_path("generate_nested_string");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    draft = msprintf("%s = {", env);

    for index = 1:size(options, "c")
        // make accessing elements simpler by introducing temporary variables
        option = options{index};
        value = values{index};
        if (option == "font") && (typeof(value) == "string")
            draft = draft + generate_color_string(option, value);
        elseif (option == "font") && (typeof(value) == "constant")
            draft = draft + msprintf("%s=%s", option, to_fonttype(index));
        elseif value == ""
            draft = draft + generate_value_string(option);
        else
            draft = draft + generate_value_string(option, value);
        end

        //last element reached?
        if index ~= size(options, "c")
            draft = draft + ", ";
        end
    end

    draft = draft + "}";

    tikzString = draft;
endfunction
