/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzStrings = generate_tikz_strings(standalone, attributes)
// Generate LaTeX strings from given graphic attributes
//
// Syntax
// tikzStrings = generate_tikz_strings(standalone, attributes)
//
// Parameters
//      standalone: boolean selecting whether a standalone file shall be generated
//      attributes: a struct containining graphical elements
//      tikzStrings: cell containing the generated strings
//
// Description
// Generates all necessary strings for a LaTeX file with TiKz support.
// If standalone is omitted, the preambel will not be added to the tikzStrings.
//
// Examples
// plot_example_simple_graph();
// attributes = gather_graphic_attributes();
// tikzStrings = generate_tikz_strings(%t, attributes);
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("standalone", "l") || ~isdef("attributes", "l")
        message = "%s: insufficient number of input arguments, 2 expected!\n";
        error(msprintf(message, "generate_tikz_strings"))
    end

    if typeof(standalone) ~= "boolean"
        message = "%s: input argument standalone is not a boolean!\n";
        error(msprintf(message, "generate_tikz_strings"))
    end

    if ~isstruct(attributes)
        message = "%s: input argument attributes is not a struct!\n";
        error(msprintf(message, "generate_tikz_strings"))
    end

    tikzStrings = cell();

    if standalone
        tikzStrings{$+1} = add_preambel();
    end

    tikzStrings{$+1} = add_color_defines(attributes);

    tikzStrings{$+1} = add_environment_beginning("document")';
    tikzStrings{$+1} = add_environment_beginning("tikzpicture")';
    tikzStrings{$+1} = "\centering";

    // TODO: add subplots/change foreach axis if only subplots have mutliple axes
    for axisii = size(attributes.axes, "r"):-1:1
        axis = attributes.axes{axisii};
        if axis.visible == "off"
            continue;
        end
        tikzStrings{$+1} = add_environment_beginning("axis")';
        tikzStrings{$+1} = add_options("axis", axisii, attributes);

        if isfield(attributes, "polylines")
            tikzStrings{$+1} = handle_polylines(attributes, axis);
        end

        tikzStrings{$+1} = add_environment_end("axis")';
    end

    tikzStrings{$+1} = add_environment_end("tikzpicture")';
    tikzStrings{$+1} = add_environment_end("document")';

endfunction
