/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function foundNodes = find_nodes(handle, elementType, nodeList)
// Finds all nodes of a given type in a handle tree
//
// Syntax
// resultNodes = find_nodes(handle, elementType, nodeList)
//
// Parameters
//      handle: handle, used as starting point (= root element)
//      elementType: string describing the elements to search for, e.g. "Axes"
//      nodeList: list needed for recursive algorithm, can be empty at call
//      foundNodes: list containing the found elements
//
// Description
// This function implements a recursive depth-first search algorithm to find
// all occurences of nodes with elementType and saves them in a list structure.
// This function is used in gather_graphic_attributes.
// NOTE: Scilab crashes when accessing list elements returned by this function,
// might be an underlying memory issue cause by scilab.
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("handle", "l")
        message = "%s: number of arguments < 1.\n";
        error(msprintf(message, "find_nodes"))
    end

    if typeof(handle) ~= "handle"
        message = "%s: handle is not a vector of handles.\n";
        error(msprintf(message, "find_nodes"))
    end

    if typeof(elementType) ~= "string"
        message = "%s: elementType is not a string.\n";
        error(msprintf(message, "find_nodes"))
    end

    if typeof(nodeList) ~= "list"
        message = "%s: nodeList is not a list.\n";
        error(msprintf(message, "find_nodes"))
    end


    foundNodes = nodeList;

    if handle.type == elementType
        foundNodes($+1) = copy(handle);
    else
        if isempty(f.children)
            return;
        end

        // expand children
        for children = handle.children'
            foundNodes = find_nodes(children, elementType, foundNodes);
        end
    end
endfunction
