/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function xs2tikz(filename, varargin)
// Convert scilab graphic to tikz
//
// Syntax
// xs2tikz(filename)
// xs2tikz(filename, doctype)
// xs2tikz(filename, doctype, license)
//
// Parameters
//      filename: path to output LaTeX file
//      doctype: either "standalone" or "embeddable"
//      license: either "license" or "no_license"
//
// Description
// This is the main function. It takes a filename string and optionally two strings:
//
// Optional argument <literal>doctype</literal> can either be "standalone" for creating
// a single, buidlable LaTeX file or "embeddable" for an insertable file. Default value is
// "standalone".
//
// The following preamble in your main document is needed for "embeddable" to work:
//
// <programlisting language="LaTeX"><![CDATA[
// \usepackage[T1]{fontenc}
// \usepackage[utf8]{inputenc}
// \usepackage{pgfplots}
// \usepackage{grffile}
// \pgfplotsset{compat=newest}
// \usetikzlibrary{plotmarks}
// \usetikzlibrary{arrows.meta}
// \usepgfplotslibrary{patchplots}
// \usepackage{amsmath}
// ]]></programlisting>
//
// Optional argument <literal>license</literal> can either be "license" for showing
// the toolbox' license information or "no_license". Default value is "no_license"
//
// Examples
// //As standalone file
// choose_plot_example("simple")
// xs2tikz("full_document.tex", "standalone");
//
// //As embeddable file
// choose_plot_example("simple")
// xs2tikz("only_graph.tex", "embeddable");
//
// //Also show the license
// choose_plot_example("simple")
// xs2tikz("more.tex", "standalone", "license")
//
// Authors
// Manuel Csapo, 2018
    [lhs, rhs] = argn();
    if 1 > rhs | rhs > 3
        message = "%s: insufficient number of input arguments, %d to %d expected!\n";
        error(msprintf(message, "xs2tikz", 1, 3))
    end

    if ~isdef("filename", "l")
        message = "%s: please provide at least a filename as input argument.\n";
        error(msprintf(message, "xs2tikz"))
    end

    // handle optional arguments, since we need to set defaults in case of ommittence
    numvarargs = length(varargin);
    optargs = list("standalone", "no_license");
    for index = 1:numvarargs
        optargs(index) = varargin(index);
    end
    [doctypeFlag, licenseFlag] = optargs(:);

    if typeof(doctypeFlag) ~= "string"
        message = "%s: input argument doctype is not a string!\n";
        error(msprintf(message, "xs2tikz"))
    end

    if typeof(licenseFlag) ~= "string"
        message = "%s: input argument license is not a string!\n";
        error(msprintf(message, "xs2tikz"))
    end

    // load internals
    path = get_function_path("xs2tikz");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    if licenseFlag == "license"
        show_license();
    end

    // workhorse goes here
    attributes = gather_graphic_attributes()

    if doctypeFlag == "standalone"
        tikzStrings = generate_tikz_strings(%t, attributes);
        printf("A standalone LaTeX file will be created!\n")
    elseif doctypeFlag == "embeddable"
        tikzStrings = generate_tikz_strings(%f, attributes);
        printf("A embeddable LaTeX file will be created!\n")
    else
        message = "%s: option %s not recognized";
        error(msprintf(message, "xs2tikz"))
    end

    save_to_file(filename, cell2mat(tikzStrings));
    printf("File %s in %s created!\n", filename, pwd());
endfunction
